@@ -1,11 +1,11 @@
 ;;; bench.el --- benchmarking utility for emacsen
 
 ;; Copyright (C) 1987,88,89,90,93,94,95,96 Free Software Foundation, Inc.
-;; $Id: bench.el,v 1.3 1999/11/27 20:49:54 martinb Exp $	
-;; $Source: /usr/CVSroot/XEmacs/xemacs-packages/libs/xemacs-devel/bench.el,v $
-;; $Revision: 1.3 $
-;; $Author: martinb $
-;; $Date: 1999/11/27 20:49:54 $
+;; $Id: bench.el,v 1.4 2001/09/08 11:01:26 adrian Exp $	
+;; $Source: /usr/CVSroot/XEmacs/packages/xemacs-packages/xemacs-devel/bench.el,v $
+;; $Revision: 1.4 $
+;; $Author: adrian $
+;; $Date: 2001/09/08 11:01:26 $
 
 ;; Author: Shane Holder <holder@rsn.hp.com>
 ;; Adapted-By: Steve Baur <steve@xemacs.org>
@@ -340,14 +340,16 @@ Expect point to be at point min"
 )
 
 ;=============================================================================
-(defconst bench-version (let ((rcsvers "$Revision: 1.3 $"))
+(defconst bench-version (let ((rcsvers "$Revision: 1.4 $"))
 			  (substring rcsvers 11 (- (length rcsvers) 2)))
   "*Version number of bench.el")
 
-(defconst bench-large-lisp-file (concat (temp-directory) "./bench-large.el")
+(defconst bench-large-lisp-file (expand-file-name
+                                 "bench-large.el" (temp-directory))
   "Large lisp file to use in benchmarks should be /temp-dir/bench-text.el")
 
-(defconst bench-small-lisp-file (concat (temp-directory) "./bench-small.el")
+(defconst bench-small-lisp-file (expand-file-name
+                                 "bench-small.el" (temp-directory))
   "Large lisp file to use in benchmarks should be /temp-dir/bench-text.el")
 
 (defconst bench-lisp-file bench-large-lisp-file)
